@@ -21,6 +21,7 @@ import json
 import warnings
 
 import six
+from six.moves.urllib.parse import urlsplit
 
 from google.api_core import page_iterator
 from google.api_core import datetime_helpers
@@ -38,6 +39,17 @@ from google.cloud.storage._signing import generate_signed_url_v4
 from google.cloud.storage.acl import BucketACL
 from google.cloud.storage.acl import DefaultObjectACL
 from google.cloud.storage.blob import Blob
+from google.cloud.storage.constants import COLDLINE_STORAGE_CLASS
+from google.cloud.storage.constants import DUAL_REGION_LOCATION_TYPE
+from google.cloud.storage.constants import (
+    DURABLE_REDUCED_AVAILABILITY_LEGACY_STORAGE_CLASS,
+)
+from google.cloud.storage.constants import MULTI_REGIONAL_LEGACY_STORAGE_CLASS
+from google.cloud.storage.constants import MULTI_REGION_LOCATION_TYPE
+from google.cloud.storage.constants import NEARLINE_STORAGE_CLASS
+from google.cloud.storage.constants import REGIONAL_LEGACY_STORAGE_CLASS
+from google.cloud.storage.constants import REGION_LOCATION_TYPE
+from google.cloud.storage.constants import STANDARD_STORAGE_CLASS
 from google.cloud.storage.notification import BucketNotification
 from google.cloud.storage.notification import NONE_PAYLOAD_FORMAT
 
@@ -129,7 +141,7 @@ class LifecycleRuleConditions(dict):
                     version.
 
     :type matches_storage_class: list(str), one or more of
-                                 :attr:`Bucket._STORAGE_CLASSES`.
+                                 :attr:`Bucket.STORAGE_CLASSES`.
     :param matches_storage_class: (optional) apply rule action to items which
                                   whose storage class matches this value.
 
@@ -243,7 +255,7 @@ class LifecycleRuleDelete(dict):
 class LifecycleRuleSetStorageClass(dict):
     """Map a lifecycle rule upating storage class of matching items.
 
-    :type storage_class: str, one of :attr:`Bucket._STORAGE_CLASSES`.
+    :type storage_class: str, one of :attr:`Bucket.STORAGE_CLASSES`.
     :param storage_class: new storage class to assign to matching items.
 
     :type kw: dict
@@ -386,38 +398,7 @@ class Bucket(_PropertyMixin):
     This is used in Bucket.delete() and Bucket.make_public().
     """
 
-    STANDARD_STORAGE_CLASS = "STANDARD"
-    """Storage class for objects accessed more than once per month."""
-
-    NEARLINE_STORAGE_CLASS = "NEARLINE"
-    """Storage class for objects accessed at most once per month."""
-
-    COLDLINE_STORAGE_CLASS = "COLDLINE"
-    """Storage class for objects accessed at most once per year."""
-
-    MULTI_REGIONAL_LEGACY_STORAGE_CLASS = "MULTI_REGIONAL"
-    """Legacy storage class.
-
-    Alias for :attr:`STANDARD_STORAGE_CLASS`.
-
-    Implies :attr:`MULTI_REGION_LOCATION_TYPE` for :attr:`location_type`.
-    """
-
-    REGIONAL_LEGACY_STORAGE_CLASS = "REGIONAL"
-    """Legacy storage class.
-
-    Alias for :attr:`STANDARD_STORAGE_CLASS`.
-
-    Implies :attr:`REGION_LOCATION_TYPE` for :attr:`location_type`.
-    """
-
-    DURABLE_REDUCED_AVAILABILITY_LEGACY_STORAGE_CLASS = "DURABLE_REDUCED_AVAILABILITY"
-    """Legacy storage class.
-
-    Similar to :attr:`NEARLINE_STORAGE_CLASS`.
-    """
-
-    _STORAGE_CLASSES = (
+    STORAGE_CLASSES = (
         STANDARD_STORAGE_CLASS,
         NEARLINE_STORAGE_CLASS,
         COLDLINE_STORAGE_CLASS,
@@ -434,24 +415,6 @@ class Bucket(_PropertyMixin):
     https://cloud.google.com/storage/docs/storage-classes
     """
 
-    MULTI_REGION_LOCATION_TYPE = "multi-region"
-    """Location type: data will be replicated across regions in a multi-region.
-
-    Provides highest availability across largest area.
-    """
-
-    REGION_LOCATION_TYPE = "region"
-    """Location type: data will be stored within a single region.
-
-    Provides lowest latency within a single region.
-    """
-
-    DUAL_REGION_LOCATION_TYPE = "dual-region"
-    """Location type: data will be stored within two primary regions.
-
-    Provides high availability and low latency across two regions.
-    """
-
     _LOCATION_TYPES = (
         MULTI_REGION_LOCATION_TYPE,
         REGION_LOCATION_TYPE,
@@ -495,6 +458,35 @@ class Bucket(_PropertyMixin):
         """
         return self._user_project
 
+    @classmethod
+    def from_string(cls, uri, client=None):
+        """Get a constructor for bucket object by URI.
+
+        :type uri: str
+        :param uri: The bucket uri pass to get bucket object.
+
+        :type client: :class:`~google.cloud.storage.client.Client` or
+                      ``NoneType``
+        :param client: Optional. The client to use.
+
+        :rtype: :class:`google.cloud.storage.bucket.Bucket`
+        :returns: The bucket object created.
+
+        Example:
+            Get a constructor for bucket object by URI..
+
+            >>> from google.cloud import storage
+            >>> from google.cloud.storage.bucket import Bucket
+            >>> client = storage.Client()
+            >>> bucket = Bucket.from_string("gs://bucket",client)
+        """
+        scheme, netloc, path, query, frag = urlsplit(uri)
+
+        if scheme != "gs":
+            raise ValueError("URI scheme must be gs")
+
+        return cls(client, name=netloc)
+
     def blob(
         self,
         blob_name,
@@ -1392,7 +1384,7 @@ class Bucket(_PropertyMixin):
           :start-after: [START add_lifecycle_set_storage_class_rule]
           :end-before: [END add_lifecycle_set_storage_class_rule]
 
-        :type storage_class: str, one of :attr:`_STORAGE_CLASSES`.
+        :type storage_class: str, one of :attr:`STORAGE_CLASSES`.
         :param storage_class: new storage class to assign to matching items.
 
         :type kw: dict
@@ -1446,8 +1438,10 @@ class Bucket(_PropertyMixin):
 
         :rtype: str or ``NoneType``
         :returns:
-            If set, one of :attr:`MULTI_REGION_LOCATION_TYPE`,
-            :attr:`REGION_LOCATION_TYPE`, or :attr:`DUAL_REGION_LOCATION_TYPE`,
+            If set, one of
+            :attr:`~google.cloud.storage.constants.MULTI_REGION_LOCATION_TYPE`,
+            :attr:`~google.cloud.storage.constants.REGION_LOCATION_TYPE`, or
+            :attr:`~google.cloud.storage.constants.DUAL_REGION_LOCATION_TYPE`,
             else ``None``.
         """
         return self._properties.get("locationType")
@@ -1609,12 +1603,14 @@ class Bucket(_PropertyMixin):
 
         :rtype: str or ``NoneType``
         :returns:
-            If set, one of :attr:`NEARLINE_STORAGE_CLASS`,
-            :attr:`COLDLINE_STORAGE_CLASS`, :attr:`STANDARD_STORAGE_CLASS`,
-            :attr:`MULTI_REGIONAL_LEGACY_STORAGE_CLASS`,
-            :attr:`REGIONAL_LEGACY_STORAGE_CLASS`,
+            If set, one of
+            :attr:`~google.cloud.storage.constants.NEARLINE_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.COLDLINE_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.STANDARD_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.MULTI_REGIONAL_LEGACY_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.REGIONAL_LEGACY_STORAGE_CLASS`,
             or
-            :attr:`DURABLE_REDUCED_AVAILABILITY_LEGACY_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.DURABLE_REDUCED_AVAILABILITY_LEGACY_STORAGE_CLASS`,
             else ``None``.
         """
         return self._properties.get("storageClass")
@@ -1627,14 +1623,16 @@ class Bucket(_PropertyMixin):
 
         :type value: str
         :param value:
-            One of :attr:`NEARLINE_STORAGE_CLASS`,
-            :attr:`COLDLINE_STORAGE_CLASS`, :attr:`STANDARD_STORAGE_CLASS`,
-            :attr:`MULTI_REGIONAL_LEGACY_STORAGE_CLASS`,
-            :attr:`REGIONAL_LEGACY_STORAGE_CLASS`,
+            One of
+            :attr:`~google.cloud.storage.constants.NEARLINE_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.COLDLINE_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.STANDARD_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.MULTI_REGIONAL_LEGACY_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.REGIONAL_LEGACY_STORAGE_CLASS`,
             or
-            :attr:`DURABLE_REDUCED_AVAILABILITY_LEGACY_STORAGE_CLASS`,
+            :attr:`~google.cloud.storage.constants.DURABLE_REDUCED_AVAILABILITY_LEGACY_STORAGE_CLASS`,
         """
-        if value not in self._STORAGE_CLASSES:
+        if value not in self.STORAGE_CLASSES:
             raise ValueError("Invalid storage class: %s" % (value,))
         self._patch_property("storageClass", value)
 
